.. MEWpy documentation master file, created by
   sphinx-quickstart on Wed Sep  2 17:04:15 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

MEWpy's documentation
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   main.md
   install.md
   simulation.md
   optimization.md
   evaluation.md
   problems.md
   germ.md
   options.md
   modules




Indices and tables
==================

* :ref:`modindex`
* :ref:`search`

